#!/bin/bash
#
# Create an archive for a language from the Bazaar repository of Launchpad
# with the same file system directories as in Git.
#
# You can change the path of the local Bazaar local branch:
#    ./language-archive.sh LANG DATE ~/dev/bzr-e18-l10n-export
# Or run with the default paths:
#    ./language-archive.sh LANG DATE
# Or run for the changes since yesterday with the default paths:
#    ./language-archive.sh LANG
# Or run for the changes since yesterday with the default paths for the current language:
#    ./language-archive.sh
#
# With
# - LANG a valid language code (eg.: eo, fr)
# - DATE the last exportation date (eg.: 2012-12-05) or 'ever' to add all translations
#
# 2014-01-03

BZR_LOCAL=$(pwd)
BZR_URL='lp:~e17-users/enlightenment/l10n-export-0.18'
PACKAGES=" \
efl-1.8/core/efl:efl \
elementary-1.8/core/elementary:elementary \
enlightenment-0.18/core/enlightenment:enlightenment \
enlightenment-0.18/enlightenment/modules/diskio:diskio \
enlightenment-0.18/enlightenment/modules/mem:mem \
mpdule-0.18/enlightenment/modules/mpdule:mpdule \
enlightenment-0.18/enlightenment/modules/net:net \
enlightenment-0.18/enlightenment/modules/places:places \
"

if [ $# -ge 1 ]; then
	LANG=$1;
fi
if [ $# -ge 2 ]; then
	DATE=$2;
else
	DATE=`date --date='1 day ago' +%Y-%m-%d`
fi
if [ $# -ge 3 ]; then
	BZR_LOCAL=$3;
fi

if [ ! -d $BZR_LOCAL ]; then
	echo "initial branch of $BZR_URL"
	bzr branch $BZR_URL $BZR_LOCAL
fi

echo "bzr update"
bzr update $BZR_LOCAL
ARCHIVE=$LANG-0.18.tar
cd $BZR_LOCAL
rm -f $ARCHIVE*

for PACKAGE in $PACKAGES; do
	PATHS=(${PACKAGE//:/ });
	FILEPATH="${PATHS[1]}/$LANG.po";
	DEST="${PATHS[0]}/po/$LANG.po";
	if [ ! -f $FILEPATH ]; then
		echo "!!!! $FILEPATH does not exist!";
		continue;
	fi
	if [ $DATE != 'ever' ]; then
		if [ `bzr log | grep $DATE | wc -l` -eq 0 ]; then continue; fi
		# ignore unmodified translations
		if [ `bzr diff -r$DATE $FILEPATH | grep '^+msgstr' -A1 | grep -v '^+msgstr ""' | grep -v '^+' | grep -v '^--' | grep -v '^$' | wc -l` -eq 0 ]; then
			continue;
		fi
	fi
	# Test validity
	msgfmt -c --statistics -o /dev/null $FILEPATH 2> /dev/null;
	if [ $? -ne 0 ]; then
		echo "!!!! $FILEPATH is invalid and not added to the archive!";
		msgfmt -c --statistics -o /dev/null $FILEPATH;
		continue;
	fi
	#
	echo "+ $DEST";
	tar --append -f $ARCHIVE $FILEPATH --transform "s:$FILEPATH:$DEST:g";
done
if [ -f $ARCHIVE ]; then
	bzip2 $ARCHIVE
	rm -f $ARCHIVE
	echo "$ARCHIVE.bz2 is created with modified translations since $DATE."
else
	echo "No translations found for $LANG since $DATE."
fi
